<?php
/**
 * Bricksy functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @subpackage Bricksy
 * @since Bricksy 1.0
 */


if ( ! function_exists( 'bricksy_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since Bricksy 1.0
	 *
	 * @return void
	 */
	function bricksy_support() {

		// Add support for block styles.
		add_theme_support( 'wp-block-styles' );

		// Enqueue editor styles.
		add_editor_style( 'style.css' );

	}

endif;

add_action( 'after_setup_theme', 'bricksy_support' );

if ( ! function_exists( 'bricksy_styles' ) ) :

	/**
	 * Enqueue styles.
	 *
	 * @since Bricksy 1.0
	 *
	 * @return void
	 */
	function bricksy_styles() {

		// Register theme stylesheet.
		wp_register_style(
			'bricksy-style',
			get_template_directory_uri() . '/style.css',
			array(),
			wp_get_theme()->get( 'Version' )
		);
		
		// Add styles inline.
		wp_add_inline_style( 'bricksy-style', bricksy_get_font_face_styles() );

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'bricksy-style' );

	}

endif;

add_action( 'wp_enqueue_scripts', 'bricksy_styles' );

if ( ! function_exists( 'bricksy_editor_styles' ) ) :

	/**
	 * Enqueue editor styles.
	 *
	 * @since Bricksy 1.0
	 *
	 * @return void
	 */
	function bricksy_editor_styles() {

		// Add styles inline.
		wp_add_inline_style( 'wp-block-library', bricksy_get_font_face_styles() );

	}

endif;

add_action( 'admin_init', 'bricksy_editor_styles' );


if ( ! function_exists( 'bricksy_get_font_face_styles' ) ) :

	/**
	 * Get font face styles.
	 * Called by functions bricksy_styles() and bricksy_editor_styles() above.
	 *
	 * @since Bricksy 1.0
	 *
	 * @return string
	 */
	function bricksy_get_font_face_styles() {

		return "
		@font-face{
			font-family: 'Source Serif Pro';
			font-weight: 200 900;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/source-serif/SourceSerif4Variable-Roman.ttf.woff2' ) . "') format('woff2');
		}

		@font-face{
			font-family: 'Source Serif Pro';
			font-weight: 200 900;
			font-style: italic;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/source-serif/SourceSerif4Variable-Italic.ttf.woff2' ) . "') format('woff2');
		}

		@font-face{
			font-family: 'Gilda Display';
			font-weight: regular;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/gilda-display/GildaDisplay-Regular.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Nunito Sans';
			font-weight: normal;
			font-style: normal;
			font-stretch: normal;
			src: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Regular.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Nunito Sans';
			font-weight: normal;
			font-style: italic;
			font-stretch: normal;
			src: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Italic.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Nunito Sans';
			font-weight: 600;
			font-style: normal;
			font-stretch: normal;
			src: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-SemiBold.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Nunito Sans';
			font-weight: 700;
			font-style: normal;
			font-stretch: normal;
			src: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Bold.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Kristi';
			font-weight: regular;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/kristi/kristi-regular.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Inconsolata';
			font-weight: regular;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/inconsolata/Inconsolata-Regular.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Inconsolata';
			font-weight: bold;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/inconsolata/Inconsolata-Bold.woff' ) . "') format('woff');
		}

		@font-face{
			font-family: 'Bestermind';
			font-weight: normal;
			font-style: normal;
			font-stretch: normal;
			src: url('" . get_theme_file_uri( 'assets/fonts/bestermind/BestermindRegular.woff' ) . "') format('woff');
		}
		";

	}

endif;
// Add block patterns
require get_template_directory() . '/inc/block-patterns.php';

// Block Styles.
require get_template_directory() . '/inc/block-styles.php';

// Theme Admin Page
require get_template_directory() . '/inc/admin/theme-admin.php';

/*--------------------------------------------------------------
# Enqueue Admin Scripts and Styles
--------------------------------------------------------------*/
if ( ! function_exists( 'bricksy_admin_scripts' ) ) :
	function bricksy_admin_scripts() {
		wp_enqueue_style( 'bricksy-admin-styles', get_template_directory_uri() . '/assets/admin/css/admin-styles.css' );
	}
	add_action( 'admin_enqueue_scripts', 'bricksy_admin_scripts' );
endif;


// Add Extendify Support
$project_name = 'bricksy';
require_once get_template_directory() . '/inc/class-partnership-notice.php';
new Extendify_Partner( 'Bricksy', array( 'themes' ));